==> huaweicloudsdkcfw-3.1.13-py2.py3-none-any.whl: huaweicloudsdkcfw/v1/model/change_protect_status_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ChangeProtectStatusRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'object_id': 'str',
        'status': 'int'
    }

    attribute_map = {
        'object_id': 'object_id',
        'status': 'status'
    }

    def __init__(self, object_id=None, status=None):
        """ChangeProtectStatusRequestBody

        The model defined in huaweicloud sdk

        :param object_id: 防护对象ID
        :type object_id: str
        :param status: 防护状态：0 开启，1 关闭
        :type status: int
        """
        
        

        self._object_id = None
        self._status = None
        self.discriminator = None

        self.object_id = object_id
        self.status = status

    @property
    def object_id(self):
        """Gets the object_id of this ChangeProtectStatusRequestBody.

        防护对象ID

        :return: The object_id of this ChangeProtectStatusRequestBody.
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this ChangeProtectStatusRequestBody.

        防护对象ID

        :param object_id: The object_id of this ChangeProtectStatusRequestBody.
        :type object_id: str
        """
        self._object_id = object_id

    @property
    def status(self):
        """Gets the status of this ChangeProtectStatusRequestBody.

        防护状态：0 开启，1 关闭

        :return: The status of this ChangeProtectStatusRequestBody.
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ChangeProtectStatusRequestBody.

        防护状态：0 开启，1 关闭

        :param status: The status of this ChangeProtectStatusRequestBody.
        :type status: int
        """
        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChangeProtectStatusRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcfw-3.1.15-py2.py3-none-any.whl: huaweicloudsdkcfw/v1/model/change_protect_status_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ChangeProtectStatusRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'object_id': 'str',
        'status': 'int'
    }

    attribute_map = {
        'object_id': 'object_id',
        'status': 'status'
    }

    def __init__(self, object_id=None, status=None):
        """ChangeProtectStatusRequestBody

        The model defined in huaweicloud sdk

        :param object_id: 防护对象id
        :type object_id: str
        :param status: 防护状态：0 开启，1 关闭
        :type status: int
        """
        
        

        self._object_id = None
        self._status = None
        self.discriminator = None

        self.object_id = object_id
        self.status = status

    @property
    def object_id(self):
        """Gets the object_id of this ChangeProtectStatusRequestBody.

        防护对象id

        :return: The object_id of this ChangeProtectStatusRequestBody.
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this ChangeProtectStatusRequestBody.

        防护对象id

        :param object_id: The object_id of this ChangeProtectStatusRequestBody.
        :type object_id: str
        """
        self._object_id = object_id

    @property
    def status(self):
        """Gets the status of this ChangeProtectStatusRequestBody.

        防护状态：0 开启，1 关闭

        :return: The status of this ChangeProtectStatusRequestBody.
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ChangeProtectStatusRequestBody.

        防护状态：0 开启，1 关闭

        :param status: The status of this ChangeProtectStatusRequestBody.
        :type status: int
        """
        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChangeProtectStatusRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
